@@ -3,18 +3,20 @@
 from django.test import TestCase
 from django.utils import timezone
 
-from django_pg_current_timestamp.test_app.models import TestModel
-from django_pg_current_timestamp import CurrentTimestamp
+from django_pg_current_timestamp.django_pg_current_timestamp_test_app.models import TestModel
+import django_pg_current_timestamp
 
 
 class CurrentTimestampTest(TestCase):
-    initiated = False
+
+    def setUp(self):
+        django_pg_current_timestamp.init()
 
     def testCurrentTimestamp(self):
         a = TestModel.objects.create(value='altavista.com')
         b = TestModel.objects.get(id=a.id)
 
-        # These shouldn't match, because the TS returned with the initial object is app-generated, whereas the queried object `b` should have the databases `CURRENT_TIMESTAMP` value.
+        # These shouldn't match, because the TS returned with the initial object is app-generated, whereas the queried object `b` should have the database's `CURRENT_TIMESTAMP` value.
         self.assertNotEqual(a.created_ts, b.created_ts)
         self.assertNotEqual(a.modified_ts, b.modified_ts)
 
